@@ -43,6 +43,18 @@ K_EXPORT_COMPONENT_FACTORY( kcm_kmrml, MrmlFactory("kmrml") )
 KCMKMrml::KCMKMrml(QWidget *parent, const char *name, const QStringList & ):
     KCModule(MrmlFactory::instance(), parent, name)
 {
+    KAboutData* ab = new KAboutData(
+        "kcmkmrml",
+        I18N_NOOP("KCMKMrml"),
+        KMRML_VERSION,
+        I18N_NOOP("Advanced Search Control Module"),
+            KAboutData::License_GPL,
+        I18N_NOOP( "Copyright 2002, Carsten Pfeiffer" ),
+        0,
+        "http://devel-home.kde.org/~pfeiffer/kmrml/" );
+    ab->addAuthor( "Carsten Pfeiffer", 0, "pfeiffer@kde.org" );
+    setAboutData( ab );
+
     QVBoxLayout *layout = new QVBoxLayout( this );
     layout->setSpacing( KDialog::spacingHint() );
     m_mainPage = new MainPage( this, "main page" );
@@ -63,7 +75,7 @@ void KCMKMrml::defaults()
 {
     if (KMessageBox::warningContinueCancel(this,
          i18n("Do you really want the configuration to be reset "
-              "to the defaults?"), i18n("Are you sure?"), KStdGuiItem::cont())
+              "to the defaults?"), i18n("Reset Configuration"), KStdGuiItem::cont())
         != KMessageBox::Continue)
         return;
 
@@ -92,34 +104,13 @@ QString KCMKMrml::quickHelp() const
                 "KDE can make use of the GNU Image Finding Tool (GIFT) to "
                 "perform queries based not just on filenames, but on "
                 "file content."
-                "<p>E.g. you can search for an image by giving an example "
-                "image, that looks similar to the one you are looking for.</p>"
-                "<p>For that to work, your image directories need to be "
-                "indexed by the GIFT server, for example.</p>"
+                "<p>For example, you can search for an image by giving an example "
+                "image that looks similar to the one you are looking for.</p>"
+                "<p>For this to work, your image directories need to be "
+                "indexed by, for example, the GIFT server.</p>"
                 "<p>Here you can configure the servers (you can also query "
                 "remote servers) and the directories to index.</p>"
         );
 }
 
-const KAboutData *KCMKMrml::aboutData() const
-{
-    static KAboutData* ab = 0;
-
-    if(!ab)
-    {
-        ab = new KAboutData(
-            "kcmkmrml",
-            I18N_NOOP("KCMKMrml"),
-            KMRML_VERSION,
-            I18N_NOOP("Advanced Search Control Module"),
-            KAboutData::License_GPL,
-            I18N_NOOP( "Copyright 2002, Carsten Pfeiffer" ),
-            0,
-            "http://devel-home.kde.org/~pfeiffer/kmrml/" );
-        ab->addAuthor( "Carsten Pfeiffer", 0, "pfeiffer@kde.org" );
-    }
-
-    return ab;
-}
-
 #include "kcmkmrml.moc"
