@@ -172,9 +172,9 @@ void PresentationWidget::keyPressEvent( QKeyEvent * e )
 {
     if (m_width == -1) return;
 	
-    if ( e->key() == Key_Left || e->key() == Key_Backspace )
+    if ( e->key() == Key_Left || e->key() == Key_Backspace || e->key() == Key_Prior )
         slotPrevPage();
-    else if ( e->key() == Key_Right || e->key() == Key_Space )
+    else if ( e->key() == Key_Right || e->key() == Key_Space || e->key() == Key_Next )
         slotNextPage();
     else if ( e->key() == Key_Escape )
     {
@@ -194,14 +194,14 @@ void PresentationWidget::wheelEvent( QWheelEvent * e )
         if ( div > 3 )
             div = 3;
         while ( div-- )
-            slotNextPage();
+            slotPrevPage();
     }
     else if ( div < 0 )
     {
         if ( div < -3 )
             div = -3;
         while ( div++ )
-            slotPrevPage();
+            slotNextPage();
     }
 }
 
@@ -320,7 +320,7 @@ void PresentationWidget::overlayClick( const QPoint & position )
         return;
 
     // compute angle relative to indicator (note coord transformation)
-    float angle = 0.5 + 0.5 * atan2f( -xPos, -yPos ) / M_PI;
+    float angle = 0.5 + 0.5 * atan2( -xPos, -yPos ) / M_PI;
     int pageIndex = (int)( angle * ( m_frames.count() - 1 ) + 0.5 );
 
     // go to selected page
@@ -523,13 +523,7 @@ void PresentationWidget::generateOverlay()
     QImage image( doublePixmap.convertToImage().smoothScale( side, side ) );
     image.setAlphaBuffer( true );
 
-    // generate a monochrome pixmap using grey level as alpha channel and
-    // a saturated hilight color as base color
-    int hue, sat, val;
-    palette().active().highlight().getHsv( &hue, &sat, &val );
-    sat = (sat + 255) / 2;
-    const QColor & color = QColor( hue, sat, val, QColor::Hsv );
-    int red = color.red(), green = color.green(), blue = color.blue(),
+    int red = 52, green = 115, blue = 178,
         pixels = image.width() * image.height();
     unsigned int * data = (unsigned int *)image.bits();
     for( int i = 0; i < pixels; ++i )
