@@ -23,6 +23,7 @@
 #include <ft2build.h>
 #include FT_FREETYPE_H
 // -- ---------------------------------------------------------- --
+#include <X11/Xlib.h>
 #include <X11/Xft/Xft.h>
 #include <X11/Xft/XftCompat.h>
 #include <stdio.h>
@@ -98,6 +99,7 @@ static const char *displayFontDirs[] = {
   "/usr/share/fonts/default/Type1",
   "/usr/share/fonts/type1/gsfonts",
   "/usr/share/fonts/default/ghostscript/",
+  "/usr/share/fonts/Type1",
   NULL
 };
 
@@ -1044,7 +1046,7 @@ FILE *GlobalParams::findToUnicodeFile(GString *name) {
 // KPDF: parse xpdf font name into family and style
 // Helvetica-BoldOblique => name=Helvetica, weight=Bold, slant=Oblique
 
-void parseStyle(QString& name, int& weight, int& slant)
+void parseStyle(QString& name, int& weight, int& slant, int& width)
 {
   if (!name.contains('-') && !name.contains(',')) return;
   QString type = name.section(QRegExp("[-,]"),-1);
@@ -1052,6 +1054,8 @@ void parseStyle(QString& name, int& weight, int& slant)
   if (type.contains("Oblique")) slant=FC_SLANT_OBLIQUE;
   if (type.contains("Italic")) slant=FC_SLANT_ITALIC;
   if (type.contains("Bold")) weight=FC_WEIGHT_BOLD;
+  if (type.contains("Light")) weight=FC_WEIGHT_LIGHT;
+  if (type.contains("Condensed")) width=FC_WIDTH_CONDENSED;
 }
 
 
@@ -1068,10 +1072,10 @@ DisplayFontParam *GlobalParams::getDisplayFont(GString *fontName) {
   dfp = (DisplayFontParam *)displayFonts->lookup(fontName);
   // KPDF: try to find font using Xft
   if (!dfp) {
-  	int weight=FC_WEIGHT_MEDIUM, slant=FC_SLANT_ROMAN;
+  	int weight=FC_WEIGHT_MEDIUM, slant=FC_SLANT_ROMAN, width=FC_WIDTH_NORMAL;
 	QString name(fontName->getCString());
-	parseStyle(name,weight,slant);
-	p = FcPatternBuild(0,FC_FAMILY,FcTypeString, name.ascii(), FC_SLANT, FcTypeInteger, slant, FC_WEIGHT, FcTypeInteger, weight, (char*)0);
+	parseStyle(name,weight,slant,width);
+	p = FcPatternBuild(0,FC_FAMILY,FcTypeString, name.ascii(), FC_SLANT, FcTypeInteger, slant, FC_WEIGHT, FcTypeInteger, weight, FC_WIDTH, FcTypeInteger, width, (char*)0);
 	if (!p) goto fin;
 	m = XftFontMatch(qt_xdisplay(),qt_xscreen(),p,&res);
 	if (!m) goto fin; 
