@@ -262,13 +262,24 @@ void PMPart::initActions( )
                                           actionCollection( ), "view_render_settings" );
    m_pViewRenderWindowAction = new KAction( i18n( "Render Window" ), 0, this, SLOT( slotViewRenderWindow( ) ),
                                             actionCollection( ), "view_render_window" );
-   m_pVisibilityLabelAction = new PMLabelAction( i18n( "Visibility Level:" ) + QString( " " ), actionCollection( ), "view_visibility_label" );
+   m_pVisibilityLabelAction = new PMLabelAction( i18n( "Visibility level:" ) + QString( " " ), actionCollection( ), "view_visibility_label" );
    m_pVisibilityLevelAction = new PMSpinBoxAction( i18n( "Visibility Level" ),
                      0, this, SLOT( slotVisibilityLevelChanged( int ) ),
                      actionCollection( ), "view_visibility_level" );
    connect( m_pVisibilityLevelAction, SIGNAL( plugged( ) ),
             SLOT( slotVisibilityActionPlugged( ) ) );
 
+   m_pGlobalDetailLabelAction = new PMLabelAction( i18n( "Global detail:" ) + QString( " " ), actionCollection( ), "global_detail_label" );
+   m_pGlobalDetailAction = new KSelectAction( i18n("Global Detail Level"), KShortcut(), actionCollection(), "global_detail_level" );
+   QStringList strList;
+   strList.append( i18n( "Very Low" ) );
+   strList.append( i18n( "Low" ) );
+   strList.append( i18n( "Medium" ) );
+   strList.append( i18n( "High" ) );
+   strList.append( i18n( "Very High" ) );
+   m_pGlobalDetailAction->setItems( strList );
+   connect( m_pGlobalDetailAction, SIGNAL( activated( int ) ), SLOT( slotGlobalDetailLevelChanged( int ) ) );
+
    // new objects
    if( isReadWrite( ) )
    {
@@ -769,6 +780,10 @@ void PMPart::saveConfig( KConfig* cfg )
    cfg->writeEntry( "PlaneSize", PMPlane::planeSize( ) );
    cfg->writeEntry( "SqeUSteps", PMSuperquadricEllipsoid::uSteps( ) );
    cfg->writeEntry( "SqeVSteps", PMSuperquadricEllipsoid::vSteps( ) );
+   cfg->writeEntry( "SphereSweepRSteps", PMSphereSweep::rSteps( ) );
+   cfg->writeEntry( "SphereSweepSSteps", PMSphereSweep::sSteps( ) );
+   cfg->writeEntry( "HeightFieldVariance", PMHeightField::variance( ) );
+   cfg->writeEntry( "GlobalDetailLevel", PMDetailObject::globalDetailLevel( ) );
 
    cfg->writeEntry( "DirectRendering", PMGLView::isDirectRenderingEnabled( ) );
 }
@@ -811,6 +826,11 @@ void PMPart::restoreConfig( KConfig* cfg )
    PMBlobCylinder::setVSteps( cfg->readNumEntry( "BlobCylinderVSteps", c_defaultBlobCylinderVSteps ) );
    PMSuperquadricEllipsoid::setUSteps( cfg->readNumEntry( "SqeUSteps", c_defaultSuperquadricEllipsoidUSteps ) );
    PMSuperquadricEllipsoid::setVSteps( cfg->readNumEntry( "SqeVSteps", c_defaultSuperquadricEllipsoidVSteps ) );
+   PMSphereSweep::setRSteps( cfg->readNumEntry( "SphereSweepRSteps", c_defaultSphereSweepRSteps ) );
+   PMSphereSweep::setSSteps( cfg->readNumEntry( "SphereSweepSSteps", c_defaultSphereSweepSSteps ) );
+   PMHeightField::setVariance( cfg->readNumEntry( "HeightFieldVariance", c_defaultHeightFieldVariance ) );
+   PMDetailObject::setGlobalDetailLevel( cfg->readNumEntry( "GlobalDetailLevel", c_defaultDetailObjectGlobalDetailLevel ) );
+   m_pGlobalDetailAction->setCurrentItem( PMDetailObject::globalDetailLevel( ) - 1 );
 
    if( PMGLView::isDirectRenderingEnabled( ) ) // otherwise it was disabled with a command line switch
       PMGLView::enableDirectRendering( cfg->readBoolEntry( "DirectRendering", true ) );
@@ -2805,6 +2825,12 @@ void PMPart::updateVisibilityLevel( )
    }
 }
 
+void PMPart::slotGlobalDetailLevelChanged( int level )
+{
+   PMDetailObject::setGlobalDetailLevel( level + 1 );
+   emit objectChanged( m_pScene, PMCViewStructure, this );
+}
+
 void PMPart::updateControlPoints( PMObject* oldActive )
 {
    PMControlPointList newCPs;
