@@ -55,9 +55,10 @@ protected:
    virtual void createTopWidgets( );
    /** */
    virtual void saveContents( );
-   
+
 private slots:
    void slotSmoothChecked( bool on );
+   void slotUVVectorsChecked( bool on );
    void slotInvertNormals( );
 
 private:
@@ -66,6 +67,9 @@ private:
    PMVectorEdit* m_pNormal[3];
    QLabel* m_pNormalLabel[3];
    QCheckBox* m_pSmooth;
+   QLabel* m_pUVVectorLabel[3];
+   PMVectorEdit* m_pUVVector[3];
+   QCheckBox* m_pUVEnabled;
    QPushButton* m_pMirror;
 };
 
