@@ -12,10 +12,10 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-// $Id: kimageholder.h,v 1.8.2.1 2003/02/11 13:29:35 mkretz Exp $
+// $Id: kimageholder.h 212185 2003-03-07 22:11:39Z waba $
 
 #ifndef _KIMAGEHOLDER_H
 #define _KIMAGEHOLDER_H
@@ -30,7 +30,7 @@ class QPoint;
 
 /**
  * @short Image widget
- * @version $Id: kimageholder.h,v 1.8.2.1 2003/02/11 13:29:35 mkretz Exp $
+ * @version $Id: kimageholder.h 212185 2003-03-07 22:11:39Z waba $
  */
 class KImageHolder : public QWidget
 {
@@ -65,12 +65,14 @@ class KImageHolder : public QWidget
 		void contextPress( const QPoint& );
 		void selected( const QRect & );
 		void wannaScroll( int dx, int dy );
+		void cursorPos( const QPoint & );
 
 	protected:
 		void mousePressEvent( QMouseEvent * );
 		void mouseMoveEvent( QMouseEvent * );
 		void mouseReleaseEvent( QMouseEvent * );
 		void paintEvent( QPaintEvent * );
+		virtual void timerEvent( QTimerEvent * );
 
 	private:
 		void drawSelect( QPainter & );
@@ -88,6 +90,8 @@ class KImageHolder : public QWidget
 
 		bool m_selected;
 		bool m_bSelecting;
+		int m_scrollTimerId;
+		int m_xOffset, m_yOffset;
 
 		QPen *m_pen;
 
