@@ -1,5 +1,5 @@
 /* This file is part of the KDE Project
-   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,14 +15,16 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-
-   $Id: kscanslider.cpp,v 1.15 2002/09/22 14:09:02 freitag Exp $
 */
 
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qspinbox.h>
 #include <qtooltip.h>
+#include <qcombobox.h>
+#include <qlabel.h>
+#include <qslider.h>
+#include <qlineedit.h>
 
 #include <kiconloader.h>
 #include <klocale.h>
@@ -49,34 +51,34 @@ KScanSlider::KScanSlider( QWidget *parent, const QString& text,
        /* connect the button click to setting the value */
        connect( m_stdButt, SIGNAL(clicked()),
 		this, SLOT(slRevertValue()));
-       
+
        QToolTip::add( m_stdButt,
 		      i18n( "Revert value back to its standard value %1" ).arg( stdValue ));
        hb->addWidget( m_stdButt, 0 );
        hb->addSpacing( 4 );
     }
 
-    slider = new QSlider( min, max, 1, min, QSlider::Horizontal, this, "AUTO_SLIDER_" );
+    slider = new QSlider( (int) min, (int)max, 1, (int)min, QSlider::Horizontal, this, "AUTO_SLIDER_" );
     slider->setTickmarks( QSlider::Below );
-    slider->setTickInterval( QMAX( (max-min) / 10, 1 ) );
-    slider->setSteps( QMAX( (max-min)/20, 1 ), QMAX( (max-min)/10, 1 ) );
+    slider->setTickInterval( int(QMAX( (max-min)/10, 1 )) );
+    slider->setSteps( int(QMAX( (max-min)/20, 1) ), int(QMAX( (max-min)/10, 1) ) );
     slider->setMinimumWidth( 140 );
     /* set a buddy */
     l1->setBuddy( slider );
-    
+
     /* create a spinbox for displaying the values */
-    m_spin = new QSpinBox( min, max,
+    m_spin = new QSpinBox( (int) min, (int) max,
 			   1, // step
 			   this );
 
-    
+
     /* make spin box changes change the slider */
     connect( m_spin, SIGNAL(valueChanged(int)), this, SLOT(slSliderChange(int)));
-    
+
     /* Handle internal number display */
     // connect(slider, SIGNAL(valueChanged(int)), numdisp, SLOT( setNum(int) ));
     connect(slider, SIGNAL(valueChanged(int)), this, SLOT( slSliderChange(int) ));
-		
+
     /* set Value 0 to the widget */
     slider->setValue( (int) min -1 );
 
@@ -84,7 +86,7 @@ KScanSlider::KScanSlider( QWidget *parent, const QString& text,
     hb->addWidget( slider, 36 );
     hb->addSpacing( 4 );
     hb->addWidget( m_spin, 0 );
-    
+
     hb->activate();
 
 }
@@ -107,7 +109,7 @@ void KScanSlider::slSetSlider( int value )
     // debug( "Slider val: %d -> %d", value, slider_val );
     kdDebug(29000) << "Setting Slider with " << value << endl;
 
-    if( value == slider->value() ) 
+    if( value == slider->value() )
     {
       kdDebug(29000) << "Returning because slider value is already == " << value << endl;
       return;
@@ -127,7 +129,7 @@ void KScanSlider::slSliderChange( int v )
     int slid = slider->value();
     if( v != slid )
        slider->setValue(v);
-    
+
     emit( valueChanged( v ));
 }
 
@@ -157,11 +159,11 @@ KScanEntry::KScanEntry( QWidget *parent, const QString& text )
 
     entry = new QLineEdit( this, "AUTO_ENTRYFIELD_E" );
     l1->setBuddy( entry );
-    connect( entry, SIGNAL( textChanged(const QString& )), 
+    connect( entry, SIGNAL( textChanged(const QString& )),
 	     this, SLOT( slEntryChange(const QString&)));
     connect( entry, SIGNAL( returnPressed()),
 	     this,  SLOT( slReturnPressed()));
- 			
+
     hb->addWidget( entry,3 );
     hb->activate();
 }
@@ -194,7 +196,7 @@ void KScanEntry::slSetEntry( const QString& t )
     if( t == entry->text() )
 	return;
     /* Important to check value to avoid recursive signals ;) */
-		
+
     entry->setText( t );
 }
 
@@ -213,24 +215,48 @@ void KScanEntry::slReturnPressed( void )
 
 KScanCombo::KScanCombo( QWidget *parent, const QString& text,
 			const QStrList& list )
-   : QHBox( parent )
+    : QHBox( parent ),
+      combo(0)
 {
-   setSpacing( 12 );
-   setMargin( 2 );
+    createCombo( text );
+    if( combo )
+        combo->insertStrList( list);
+    combolist = list;
+}
 
-   combolist = list;
+KScanCombo::KScanCombo( QWidget *parent, const QString& text,
+			const QStringList& list )
+    : QHBox( parent ),
+      combo(0)
+{
+    createCombo( text );
+    if( combo )
+        combo->insertStringList( list );
+
+    for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
+        combolist.append( (*it).local8Bit() );
+    }
+}
+
+
+void KScanCombo::createCombo( const QString& text )
+{
+    setSpacing( 12 );
+    setMargin( 2 );
+
+
+    (void) new QLabel( text, this, "AUTO_COMBOLABEL" );
 
-   (void) new QLabel( text, this, "AUTO_COMBOLABEL" );
- 	
     combo = new QComboBox( this, "AUTO_COMBO" );
-    combo->insertStrList( &combolist);
 
     connect( combo, SIGNAL(activated( const QString &)), this,
-		    SLOT( slComboChange( const QString &)));
+             SLOT( slComboChange( const QString &)));
     connect( combo, SIGNAL(activated( int )),
 	     this,  SLOT(slFireActivated(int)));
+
 }
 
+
 void KScanCombo::slSetEntry( const QString &t )
 {
     if( t.isNull() ) 	return;
@@ -239,7 +265,7 @@ void KScanCombo::slSetEntry( const QString &t )
     /* Important to check value to avoid recursive signals ;) */
     if( i == combo->currentItem() )
 	return;
-		
+
     if( i > -1 )
 	combo->setCurrentItem( i );
     else
